<a id="mypy-boto3-forecast"></a>

# mypy-boto3-forecast

[![PyPI - mypy-boto3-forecast](https://img.shields.io/pypi/v/mypy-boto3-forecast.svg?color=blue)](https://pypi.org/project/mypy-boto3-forecast)
[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/mypy-boto3-forecast.svg?color=blue)](https://pypi.org/project/mypy-boto3-forecast)
[![Docs](https://img.shields.io/readthedocs/mypy-boto3-builder.svg?color=blue)](https://mypy-boto3-builder.readthedocs.io/)
[![PyPI - Downloads](https://img.shields.io/pypi/dw/mypy-boto3-forecast?color=blue)](https://pypistats.org/packages/mypy-boto3-forecast)

![boto3.typed](https://github.com/vemel/mypy_boto3_builder/raw/master/logo.png)

Type annotations for
[boto3.ForecastService 1.18.47](https://boto3.amazonaws.com/v1/documentation/api/1.18.47/reference/services/forecast.html#ForecastService)
service compatible with [VSCode](https://code.visualstudio.com/),
[PyCharm](https://www.jetbrains.com/pycharm/),
[Emacs](https://www.gnu.org/software/emacs/),
[Sublime Text](https://www.sublimetext.com/),
[mypy](https://github.com/python/mypy),
[pyright](https://github.com/microsoft/pyright) and other tools.

Generated by
[mypy-boto3-builder 5.3.1](https://github.com/vemel/mypy_boto3_builder).

More information can be found on
[boto3-stubs](https://pypi.org/project/boto3-stubs/) page and in
[mypy-boto3-forecast docs](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_forecast/)

See how it helps to find and fix potential bugs:

![boto3-stubs demo](https://github.com/vemel/mypy_boto3_builder/raw/master/demo.gif)

- [mypy-boto3-forecast](#mypy-boto3-forecast)
  - [How to install](#how-to-install)
  - [Usage](#usage)
    - [VSCode](#vscode)
    - [PyCharm](#pycharm)
    - [Other IDEs](#other-ides)
    - [mypy](#mypy)
    - [pyright](#pyright)
  - [Explicit type annotations](#explicit-type-annotations)
    - [Client annotations](#client-annotations)
    - [Paginators annotations](#paginators-annotations)
    - [Literals](#literals)
    - [Typed dictionaries](#typed-dictionaries)
  - [Versioning](#versioning)
  - [Documentation](#documentation)
  - [Support and contributing](#support-and-contributing)

<a id="how-to-install"></a>

## How to install

Install `boto3-stubs` for `ForecastService` service.

```bash
python -m pip install boto3-stubs[forecast]
```

<a id="usage"></a>

## Usage

<a id="vscode"></a>

### VSCode

- Install
  [Python extension](https://marketplace.visualstudio.com/items?itemName=ms-python.python)
- Install
  [Pylance extension](https://marketplace.visualstudio.com/items?itemName=ms-python.vscode-pylance)
- Set `Pylance` as your Python Language Server
- Install `boto-stubs[forecast]` in your environment:
  `python -m pip install 'boto3-stubs[forecast]'`

Both type checking and auto-complete should work for `ForecastService` service.
No explicit type annotations required, write your `boto3` code as usual.

<a id="pycharm"></a>

### PyCharm

- Install `boto-stubs[forecast]` in your environment:
  `python -m pip install 'boto3-stubs[forecast]'`

Both type checking and auto-complete should work for `ForecastService` service.
No explicit type annotations required, write your `boto3` code as usual.
Auto-complete can be slow on big projects or if you have a lot of installed
`boto3-stubs` submodules.

<a id="other-ides"></a>

### Other IDEs

Not tested, but as long as your IDE supports `mypy` or `pyright`, everything
should work.

<a id="mypy"></a>

### mypy

- Install `mypy`: `python -m pip install mypy`
- Install `boto-stubs[forecast]` in your environment:
  `python -m pip install 'boto3-stubs[forecast]'`
- Run `mypy` as usual

Type checking should work for `ForecastService` service. No explicit type
annotations required, write your `boto3` code as usual.

<a id="pyright"></a>

### pyright

- Install `pyright`: `yarn global add pyright`
- Install `boto-stubs[forecast]` in your environment:
  `python -m pip install 'boto3-stubs[forecast]'`
- Optionally, you can install `boto3-stubs` to `typings` folder.

Type checking should work for `ForecastService` service. No explicit type
annotations required, write your `boto3` code as usual.

<a id="explicit-type-annotations"></a>

## Explicit type annotations

<a id="client-annotations"></a>

### Client annotations

`ForecastServiceClient` provides annotations for `boto3.client("forecast")`.

```python
import boto3

from mypy_boto3_forecast import ForecastServiceClient

client: ForecastServiceClient = boto3.client("forecast")

# now client usage is checked by mypy and IDE should provide code auto-complete

# works for session as well
session = boto3.session.Session(region="us-west-1")
session_client: ForecastServiceClient = session.client("forecast")
```

<a id="paginators-annotations"></a>

### Paginators annotations

`mypy_boto3_forecast.paginator` module contains type annotations for all
paginators.

```python
from mypy_boto3_forecast import ForecastServiceClient
from mypy_boto3_forecast.paginator import (
    ListDatasetGroupsPaginator,
    ListDatasetImportJobsPaginator,
    ListDatasetsPaginator,
    ListForecastExportJobsPaginator,
    ListForecastsPaginator,
    ListPredictorBacktestExportJobsPaginator,
    ListPredictorsPaginator,
)

client: ForecastServiceClient = boto3.client("forecast")

# Explicit type annotations are optional here
# Type should be correctly discovered by mypy and IDEs
# VSCode requires explicit type annotations
list_dataset_groups_paginator: ListDatasetGroupsPaginator = client.get_paginator("list_dataset_groups")
list_dataset_import_jobs_paginator: ListDatasetImportJobsPaginator = client.get_paginator("list_dataset_import_jobs")
list_datasets_paginator: ListDatasetsPaginator = client.get_paginator("list_datasets")
list_forecast_export_jobs_paginator: ListForecastExportJobsPaginator = client.get_paginator("list_forecast_export_jobs")
list_forecasts_paginator: ListForecastsPaginator = client.get_paginator("list_forecasts")
list_predictor_backtest_export_jobs_paginator: ListPredictorBacktestExportJobsPaginator = client.get_paginator("list_predictor_backtest_export_jobs")
list_predictors_paginator: ListPredictorsPaginator = client.get_paginator("list_predictors")
```

<a id="literals"></a>

### Literals

`mypy_boto3_forecast.literals` module contains literals extracted from shapes
that can be used in user code for type checking.

```python
from mypy_boto3_forecast.literals import (
    AttributeTypeType,
    AutoMLOverrideStrategyType,
    DatasetTypeType,
    DomainType,
    EvaluationTypeType,
    FeaturizationMethodNameType,
    FilterConditionStringType,
    ListDatasetGroupsPaginatorName,
    ListDatasetImportJobsPaginatorName,
    ListDatasetsPaginatorName,
    ListForecastExportJobsPaginatorName,
    ListForecastsPaginatorName,
    ListPredictorBacktestExportJobsPaginatorName,
    ListPredictorsPaginatorName,
    OptimizationMetricType,
    ScalingTypeType,
    ServiceName,
)

def check_value(value: AttributeTypeType) -> bool:
    ...
```

<a id="typed-dictionaries"></a>

### Typed dictionaries

`mypy_boto3_forecast.type_defs` module contains structures and shapes assembled
to typed dictionaries for additional type checking.

```python
from mypy_boto3_forecast.type_defs import (
    CategoricalParameterRangeTypeDef,
    ContinuousParameterRangeTypeDef,
    CreateDatasetGroupRequestRequestTypeDef,
    CreateDatasetGroupResponseTypeDef,
    CreateDatasetImportJobRequestRequestTypeDef,
    CreateDatasetImportJobResponseTypeDef,
    CreateDatasetRequestRequestTypeDef,
    CreateDatasetResponseTypeDef,
    CreateForecastExportJobRequestRequestTypeDef,
    CreateForecastExportJobResponseTypeDef,
    CreateForecastRequestRequestTypeDef,
    CreateForecastResponseTypeDef,
    CreatePredictorBacktestExportJobRequestRequestTypeDef,
    CreatePredictorBacktestExportJobResponseTypeDef,
    CreatePredictorRequestRequestTypeDef,
    CreatePredictorResponseTypeDef,
    DataDestinationTypeDef,
    DataSourceTypeDef,
    DatasetGroupSummaryTypeDef,
    DatasetImportJobSummaryTypeDef,
    DatasetSummaryTypeDef,
    DeleteDatasetGroupRequestRequestTypeDef,
    DeleteDatasetImportJobRequestRequestTypeDef,
    DeleteDatasetRequestRequestTypeDef,
    DeleteForecastExportJobRequestRequestTypeDef,
    DeleteForecastRequestRequestTypeDef,
    DeletePredictorBacktestExportJobRequestRequestTypeDef,
    DeletePredictorRequestRequestTypeDef,
    DeleteResourceTreeRequestRequestTypeDef,
    DescribeDatasetGroupRequestRequestTypeDef,
    DescribeDatasetGroupResponseTypeDef,
    DescribeDatasetImportJobRequestRequestTypeDef,
    DescribeDatasetImportJobResponseTypeDef,
    DescribeDatasetRequestRequestTypeDef,
    DescribeDatasetResponseTypeDef,
    DescribeForecastExportJobRequestRequestTypeDef,
    DescribeForecastExportJobResponseTypeDef,
    DescribeForecastRequestRequestTypeDef,
    DescribeForecastResponseTypeDef,
    DescribePredictorBacktestExportJobRequestRequestTypeDef,
    DescribePredictorBacktestExportJobResponseTypeDef,
    DescribePredictorRequestRequestTypeDef,
    DescribePredictorResponseTypeDef,
    EncryptionConfigTypeDef,
    ErrorMetricTypeDef,
    EvaluationParametersTypeDef,
    EvaluationResultTypeDef,
    FeaturizationConfigTypeDef,
    FeaturizationMethodTypeDef,
    FeaturizationTypeDef,
    FilterTypeDef,
    ForecastExportJobSummaryTypeDef,
    ForecastSummaryTypeDef,
    GetAccuracyMetricsRequestRequestTypeDef,
    GetAccuracyMetricsResponseTypeDef,
    HyperParameterTuningJobConfigTypeDef,
    InputDataConfigTypeDef,
    IntegerParameterRangeTypeDef,
    ListDatasetGroupsRequestRequestTypeDef,
    ListDatasetGroupsResponseTypeDef,
    ListDatasetImportJobsRequestRequestTypeDef,
    ListDatasetImportJobsResponseTypeDef,
    ListDatasetsRequestRequestTypeDef,
    ListDatasetsResponseTypeDef,
    ListForecastExportJobsRequestRequestTypeDef,
    ListForecastExportJobsResponseTypeDef,
    ListForecastsRequestRequestTypeDef,
    ListForecastsResponseTypeDef,
    ListPredictorBacktestExportJobsRequestRequestTypeDef,
    ListPredictorBacktestExportJobsResponseTypeDef,
    ListPredictorsRequestRequestTypeDef,
    ListPredictorsResponseTypeDef,
    ListTagsForResourceRequestRequestTypeDef,
    ListTagsForResourceResponseTypeDef,
    MetricsTypeDef,
    PaginatorConfigTypeDef,
    ParameterRangesTypeDef,
    PredictorBacktestExportJobSummaryTypeDef,
    PredictorExecutionDetailsTypeDef,
    PredictorExecutionTypeDef,
    PredictorSummaryTypeDef,
    ResponseMetadataTypeDef,
    S3ConfigTypeDef,
    SchemaAttributeTypeDef,
    SchemaTypeDef,
    StatisticsTypeDef,
    StopResourceRequestRequestTypeDef,
    SupplementaryFeatureTypeDef,
    TagResourceRequestRequestTypeDef,
    TagTypeDef,
    TestWindowSummaryTypeDef,
    UntagResourceRequestRequestTypeDef,
    UpdateDatasetGroupRequestRequestTypeDef,
    WeightedQuantileLossTypeDef,
    WindowSummaryTypeDef,
)

def get_structure() -> CategoricalParameterRangeTypeDef:
    return {
      ...
    }
```

<a id="versioning"></a>

## Versioning

`mypy-boto3-forecast` version is the same as related `boto3` version and
follows [PEP 440](https://www.python.org/dev/peps/pep-0440/) format.

<a id="documentation"></a>

## Documentation

All type annotations can be found in
[mypy-boto3-forecast docs](https://vemel.github.io/boto3_stubs_docs/mypy_boto3_forecast/)

<a id="support-and-contributing"></a>

## Support and contributing

This package is auto-generated. Please reports any bugs or request new features
in [mypy-boto3-builder](https://github.com/vemel/mypy_boto3_builder/issues/)
repository.
